@@ -49,11 +49,13 @@ from slixmpp.plugins.xep_0045.stanza import (
     MUCUserItem,
 )
 from slixmpp.types import (
+    JidStr,
     MucRole,
     MucAffiliation,
     MucRoomItem,
     MucRoomItemKeys,
     PresenceArgs,
+    PresenceShows,
 )
 
 JoinResult = Tuple[Presence, Message, List[Presence], List[Message]]
@@ -187,7 +189,7 @@ class XEP_0045(BasePlugin):
     def _handle_config_change(self, msg: Message):
         """Handle a MUC configuration change (with status code)."""
         self.xmpp.event('groupchat_config_status', msg)
-        self.xmpp.event('muc::%s::config_status' % msg['from'].bare , msg)
+        self.xmpp.event('muc::%s::config_status' % msg['from'].bare, msg)
 
     def _client_handle_presence(self, pr: Presence):
         """As a client, handle a presence stanza"""
@@ -264,7 +266,7 @@ class XEP_0045(BasePlugin):
                             seconds: Optional[int] = None,
                             since: Optional[datetime] = None,
                             presence_options: Optional[PresenceArgs] = None,
-                            timeout: Optional[int] = None) -> JoinResult:
+                            timeout: int = 300) -> JoinResult:
         """
         Try to join a MUC and block until we are joined or get an error.
 
@@ -310,7 +312,7 @@ class XEP_0045(BasePlugin):
         stanza.send()
         return await self._await_join(room, timeout)
 
-    async def _await_join(self, room: JID, timeout: Optional[int] = None) -> JoinResult:
+    async def _await_join(self, room: JID, timeout: int = 300) -> JoinResult:
         """Do the heavy lifting for awaiting a MUC join
 
         A muc join, once the join stanza is sent, is:
@@ -358,7 +360,7 @@ class XEP_0045(BasePlugin):
         return (pres, subject, occupant_buffer, history_buffer)
 
     def join_muc(self, room: JID, nick: str, maxhistory="0", password='',
-                 pstatus='', pshow='', pfrom='') -> asyncio.Future:
+                 pstatus='', pshow: PresenceShows='chat', pfrom: JidStr='') -> asyncio.Future:
         """ Join the specified room, requesting 'maxhistory' lines of history.
 
         .. deprecated:: 1.8.0
@@ -412,7 +414,7 @@ class XEP_0045(BasePlugin):
             )
         del self.rooms[room]
 
-    def set_subject(self, room: JID, subject: str, *, mfrom: Optional[JID] = None):
+    def set_subject(self, room: JidStr, subject: str, *, mfrom: Optional[JID] = None):
         """Set a room’s subject.
 
         :param room: JID of the room.
@@ -423,7 +425,7 @@ class XEP_0045(BasePlugin):
         msg['subject'] = subject
         msg.send()
 
-    async def get_room_config(self, room: JID, ifrom: Optional[JID] = None,
+    async def get_room_config(self, room: JidStr, ifrom: Optional[JID] = None,
                               **iqkwargs) -> Form:
         """Get the room config form in 0004 plugin format.
 
@@ -438,7 +440,7 @@ class XEP_0045(BasePlugin):
             raise ValueError("Configuration form not found")
         return form
 
-    async def set_room_config(self, room: JID, config: Form, *,
+    async def set_room_config(self, room: JidStr, config: Form, *,
                               ifrom: Optional[JID] = None, **iqkwargs):
         """Send a room config form.
 
@@ -451,8 +453,8 @@ class XEP_0045(BasePlugin):
         iq = self.xmpp.make_iq_set(query, ito=room, ifrom=ifrom)
         await iq.send(**iqkwargs)
 
-    async def cancel_config(self, room: JID, *,
-                            ifrom: Optional[JID] = None, **iqkwargs):
+    async def cancel_config(self, room: JidStr, *,
+                            ifrom: Optional[JidStr] = None, **iqkwargs):
         """Cancel a requested config form.
 
         :param room: Room to cancel the form for.
@@ -462,8 +464,8 @@ class XEP_0045(BasePlugin):
         iq = self.xmpp.make_iq_set(query, ito=room, ifrom=ifrom)
         await iq.send(**iqkwargs)
 
-    async def destroy(self, room: JID, reason: str = '', altroom: Optional[JID] = None, *,
-                      ifrom: Optional[JID] = None, **iqkwargs):
+    async def destroy(self, room: JidStr, reason: str = '', altroom: Optional[JidStr] = None, *,
+                      ifrom: Optional[JidStr] = None, **iqkwargs):
         """Destroy a room.
 
         :param room: Room JID to destroy.
@@ -479,10 +481,10 @@ class XEP_0045(BasePlugin):
             iq['mucowner_query']['destroy']['reason'] = reason
         await iq.send(**iqkwargs)
 
-    async def set_affiliation(self, room: JID, affiliation: MucAffiliation, *,
-                              jid: Optional[JID] = None,
+    async def set_affiliation(self, room: JidStr, affiliation: MucAffiliation, *,
+                              jid: Optional[JidStr] = None,
                               nick: Optional[str] = None, reason: str = '',
-                              ifrom: Optional[JID] = None, **iqkwargs):
+                              ifrom: Optional[JidStr] = None, **iqkwargs):
         """ Change room affiliation for a JID or nickname.
 
         :param room: Room to modify.
@@ -493,7 +495,7 @@ class XEP_0045(BasePlugin):
         if affiliation not in AFFILIATIONS:
             raise ValueError('%s is not a valid affiliation' % affiliation)
         if affiliation == 'outcast' and not jid:
-            raise ValueError('Outcast affiliation requires a using a jid')
+            raise ValueError('Outcast affiliation requires using a jid')
         if not any((jid, nick)):
             raise ValueError('One of jid or nick must be set')
         iq = self.xmpp.make_iq_set(ito=room, ifrom=ifrom)
@@ -506,8 +508,8 @@ class XEP_0045(BasePlugin):
             iq['mucadmin_query']['item']['reason'] = reason
         await iq.send(**iqkwargs)
 
-    async def get_affiliation_list(self, room: JID, affiliation: MucAffiliation, *,
-                                   ifrom: Optional[JID] = None, **iqkwargs) -> List[JID]:
+    async def get_affiliation_list(self, room: JidStr, affiliation: MucAffiliation, *,
+                                   ifrom: Optional[JidStr] = None, **iqkwargs) -> List[JID]:
         """Get a list of JIDs with the specified affiliation
 
         :param room: Room to get affiliations from.
@@ -518,9 +520,9 @@ class XEP_0045(BasePlugin):
         result = await iq.send(**iqkwargs)
         return [item['jid'] for item in result['mucadmin_query']]
 
-    async def send_affiliation_list(self, room: JID,
-                                    affiliations: List[Tuple[JID, MucAffiliation]], *,
-                                    ifrom: Optional[JID] = None, **iqkwargs):
+    async def send_affiliation_list(self, room: JidStr,
+                                    affiliations: List[Tuple[JidStr, MucAffiliation]], *,
+                                    ifrom: Optional[JidStr] = None, **iqkwargs):
         """Send an affiliation delta list.
 
         :param room: Room to send the affiliations to.
@@ -534,8 +536,8 @@ class XEP_0045(BasePlugin):
             iq['mucadmin_query'].append(item)
         await iq.send(**iqkwargs)
 
-    async def set_role(self, room: JID, nick: str, role: MucRole, *,
-                       reason: str = '', ifrom: Optional[JID] = None, **iqkwargs):
+    async def set_role(self, room: JidStr, nick: str, role: MucRole, *,
+                       reason: str = '', ifrom: Optional[JidStr] = None, **iqkwargs):
         """ Change role property of a nick in a room.
             Typically, roles are temporary (they last only as long as you are in the
             room), whereas affiliations are permanent (they last across groupchat
@@ -555,8 +557,8 @@ class XEP_0045(BasePlugin):
             iq['mucadmin_query']['item']['reason'] = reason
         await iq.send(**iqkwargs)
 
-    async def get_roles_list(self, room: JID, role: MucRole, *,
-                             ifrom: Optional[JID] = None, **iqkwargs) -> List[str]:
+    async def get_roles_list(self, room: JidStr, role: MucRole, *,
+                             ifrom: Optional[JidStr] = None, **iqkwargs) -> List[str]:
         """"Get a list of JIDs with the specified role
 
         :param room: Room to get roles from.
@@ -567,8 +569,8 @@ class XEP_0045(BasePlugin):
         result = await iq.send(**iqkwargs)
         return [item['nick'] for item in result['mucadmin_query']]
 
-    async def send_role_list(self, room: JID, roles: List[Tuple[str, MucRole]], *,
-                             ifrom: Optional[JID] = None, **iqkwargs):
+    async def send_role_list(self, room: JidStr, roles: List[Tuple[str, MucRole]], *,
+                             ifrom: Optional[JidStr] = None, **iqkwargs):
         """Send a role delta list.
 
         :param room: Room to send the roles to.
@@ -582,8 +584,8 @@ class XEP_0045(BasePlugin):
             iq['mucadmin_query'].append(item)
         await iq.send(**iqkwargs)
 
-    def invite(self, room: JID, jid: JID, reason: str = '', *,
-               mfrom: Optional[JID] = None):
+    def invite(self, room: JidStr, jid: JidStr, reason: str = '', *,
+               mfrom: Optional[JidStr] = None):
         """ Invite a jid to a room (mediated invitation).
 
         :param room: Room to invite the user in.
@@ -596,8 +598,8 @@ class XEP_0045(BasePlugin):
             msg['muc']['invite']['reason'] = reason
         self.xmpp.send(msg)
 
-    def invite_server(self, room: JID, jid: JID,
-                         invite_from: JID, reason: str = ''):
+    def invite_server(self, room: JidStr, jid: JidStr,
+                         invite_from: JidStr, reason: str = ''):
         """Send a mediated invite to a user, as a MUC service.
 
         .. versionadded:: 1.8.0
@@ -615,8 +617,8 @@ class XEP_0045(BasePlugin):
             msg['muc']['invite']['reason'] = reason
         msg.send()
 
-    def decline(self, room: JID, jid: JID, reason: str = '', *,
-                mfrom: Optional[JID] = None):
+    def decline(self, room: JidStr, jid: JidStr, reason: str = '', *,
+                mfrom: Optional[JidStr] = None):
         """Decline a mediated invitation.
 
         :param room: Room the invitation came from.
@@ -629,7 +631,7 @@ class XEP_0045(BasePlugin):
             msg['muc']['decline']['reason'] = reason
         self.xmpp.send(msg)
 
-    def request_voice(self, room: JID, role: str, *, mfrom: Optional[JID] = None):
+    def request_voice(self, room: JidStr, role: str, *, mfrom: Optional[JidStr] = None):
         """Request voice in a moderated room.
 
         :param room: Room to request voice from.
@@ -646,29 +648,49 @@ class XEP_0045(BasePlugin):
         """Check if a JID is present in a room.
 
         :param room: Room to check.
-        :param jid: JID to check.
+        :param jid: FULL JID to check.
         """
+        bare_match = False
         for nick in self.rooms[room]:
             entry = self.rooms[room][nick]
             if not entry.get('jid'):
                 continue
-            if entry is not None and entry['jid'].full == jid:
+
+            if entry['jid'] == jid.full:
                 return True
-        return False
+            elif JID(entry['jid']).bare == jid.bare:
+                bare_match = True
+        
+        if bare_match:
+            logging.info(
+                "Could not retrieve full JID, falling back to bare JID for %s in %s",
+                jid, room
+            )
+        return bare_match
 
     def get_nick(self, room: JID, jid: JID) -> Optional[str]:
         """Get the nickname of a specific JID in a room.
 
         :param room: Room to inspect.
-        :param jid: JID whose nick to return.
+        :param jid: FULL JID whose nick to return.
         """
+        bare_match = None
         for nick in self.rooms[room]:
             entry = self.rooms[room][nick]
             if not entry.get('jid'):
                 continue
-            if entry is not None and entry['jid'].full == jid:
+
+            if entry['jid'] == jid.full:
                 return nick
-        return None
+            elif JID(entry['jid']).bare == jid.bare:
+                bare_match = nick
+        
+        if bare_match:
+            logging.info(
+                "Could not retrieve full JID, falling back to bare JID for %s in %s",
+                jid, room
+            )
+        return bare_match
 
     def get_joined_rooms(self) -> List[JID]:
         """Get the list of rooms we sent a join presence to
@@ -704,7 +726,7 @@ class XEP_0045(BasePlugin):
             raise ValueError("Room %s is not joined" % room)
         return list(self.rooms[room].keys())
 
-    def get_users_by_affiliation(self, room: JID, affiliation='member', *, ifrom: Optional[JID] = None):
+    def get_users_by_affiliation(self, room: JidStr, affiliation='member', *, ifrom: Optional[JidStr] = None):
         # Preserve old API
         if affiliation not in AFFILIATIONS:
             raise ValueError("Affiliation %s does not exist" % affiliation)
