@@ -732,6 +732,9 @@ class ElementBase(object):
                 return plugin[full_attrib]
             return plugin
         else:
+            # XXX: This is legacy from SleekXMPP
+            #      We've probably missed the opportunity to fix it
+            logging.warning("Unknown stanza interface: %s" % full_attrib)
             return ''
 
     def __setitem__(self, attrib: str, value: Any) -> Any:
@@ -1230,7 +1233,7 @@ class ElementBase(object):
             if type(item) == XML_TYPE:
                 return self.appendxml(item)
             else:
-                raise TypeError
+                raise TypeError(f"Cannot append {item!r} to a stanza")
         self.xml.append(item.xml)
         if item.__class__ == self.plugin_tag_map.get(item.tag_name(), None):
             self.init_plugin(item.plugin_attrib,
