@@ -524,7 +524,7 @@ class XMLStream(asyncio.BaseProtocol):
             else:
                 self.loop.run_until_complete(self.disconnected)
         else:
-            tasks: List[Awaitable] = [asyncio.Task(asyncio.sleep(timeout))]
+            tasks: List[Union[asyncio.Task, asyncio.Future]] = [asyncio.Task(asyncio.sleep(timeout))]
             if not forever:
                 tasks.append(self.disconnected)
             self.loop.run_until_complete(asyncio.wait(tasks))
@@ -850,6 +850,8 @@ class XMLStream(asyncio.BaseProtocol):
             log.debug("Connection error:", exc_info=True)
             self.disconnect()
             return False
+        if transp is None:
+            raise Exception("Transport should not be none")
         der_cert = transp.get_extra_info("ssl_object").getpeercert(True)
         pem_cert = ssl.DER_cert_to_PEM_cert(der_cert)
         self.event('ssl_cert', pem_cert)
@@ -1348,6 +1350,7 @@ class XMLStream(asyncio.BaseProtocol):
             if isinstance(data, (RootStanza, str)) and not passthrough:
                 self.__queued_stanzas.append((data, use_filters))
                 log.debug('NOT SENT: %s %s', type(data), data)
+                self.event('stanza_not_sent', data)
                 return
         self.waiting_queue.put_nowait((data, use_filters))
 
@@ -1411,7 +1414,11 @@ class XMLStream(asyncio.BaseProtocol):
 
         # Convert the raw XML object into a stanza object. If no registered
         # stanza type applies, a generic StanzaBase stanza will be used.
-        stanza: Optional[StanzaBase] = self._build_stanza(xml)
+        try:
+            stanza: Optional[StanzaBase] = self._build_stanza(xml)
+        except Exception as exc:
+            log.exception("Unable to parse stanza: %s,\n%s", exc, xml)
+            stanza = None
         for filter in self.__filters['in']:
             if stanza is not None:
                 filter = cast(SyncFilter, filter)
